#!/usr/bin/env python
# -*- coding: utf-8 -*-

from analyzer import Analyzer
from argparse import ArgumentParser
from logger import logger
from monitor import Monitor

def main():
    parser = ArgumentParser(description='This is a link analysis tool that can customize keywords and output excel')
    parser.add_argument('--mode', default='auto', type=str, help='link analyze mode, auto or sauto')
    parser.add_argument('--automodefile', default='', type=str, help='choose param file in auto mode, '
                                                                     'include browser path and urls')
    parser.add_argument('--keywords', default=[], nargs='+', help='output the link which keywords in')
    parser.add_argument('--nokeywords', default=[], nargs='+', help='output the link which nokeywords no in')
    parser.add_argument('--extractkeys', default=[], nargs='+', help='extract keys to excel column')

    args = parser.parse_args()
    logger("param: " + str(args))
    try:
        if args.mode == "auto":
            logger('start auto analyzer')
            analyzer = Analyzer(args.keywords, args.nokeywords, args.extractkeys)
            analyzer.start(args.automodefile)
            logger('finish auto analyzer')
        elif args.mode == "sauto":
            logger('start manual analyzer')
            monitor = Monitor(args.keywords, args.nokeywords, args.extractkeys)
            monitor.start()
            logger('finish manual analyzer')
    except KeyboardInterrupt:
        exit()

if __name__ == '__main__':
    main()
    logger('finish main')



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : pengjun.pj

from setuptools import setup, find_packages

setup(
    name='link-analyze',
    version='0.0.0.5',
    description='for link theft analyze, input url , output theft url',
    author='peter',
    author_email='peter517@126.com',
    url='',
    py_modules=['link-analyze'],
    install_requires=[
        "openpyxl >= 2.4.9", "selenium>=3.7.0","scapy>=2.3.2"
    ],
    python_requires=">=2.6, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
    license='GPL',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    entry_points={'console_scripts': [
        'link-analyze = link_analyze.main:main']},
)



# --*--coding: utf-8 --*--

import os
import time

REQ_URLS_FILE = open('link-analyze-log.txt', 'a')

def logger(message, write=True):
    w = '\033[0m'
    g = '\033[32m'
    message = str(message)
    cur_time = time.strftime('%a, %d %b %Y %H:%M:%S %z: ')
    # write log message to log file if `write == true`
    if write:
        REQ_URLS_FILE.write(''.join([str(cur_time), message, '\n']))
        REQ_URLS_FILE.flush()
        os.fsync(REQ_URLS_FILE.fileno())
    print(''.join([g, str(cur_time), w, message]))
